### Publish a new package

```
>>> import bytegain.custom.cust.apartmentlist.al_xgb
/Users/tomcollier/dev/github.com/apartmentlist/bytegain-training/VIRTUAL/lib/python2.7/site-packages/matplotlib/font_manager.py:281: UserWarning: Matplotlib is building the font cache using fc-list. This may take a moment.
  'Matplotlib is building the font cache using fc-list. '
/Users/tomcollier/dev/github.com/apartmentlist/bytegain-training/VIRTUAL/lib/python2.7/site-packages/Cython/Compiler/Main.py:369: FutureWarning: Cython directive 'language_level' not set, using 2 for now (Py2). This will change in a later release! File: /Users/tomcollier/dev/github.com/apartmentlist/bytegain-training/bytegain/custom/model_data/bucket.pyx
  tree = Parsing.p_module(s, pxd, full_module_name)
/Users/tomcollier/dev/github.com/apartmentlist/bytegain-training/VIRTUAL/lib/python2.7/site-packages/Cython/Compiler/Main.py:369: FutureWarning: Cython directive 'language_level' not set, using 2 for now (Py2). This will change in a later release! File: /Users/tomcollier/dev/github.com/apartmentlist/bytegain-training/bytegain/custom/model_data/extractor.pyx
  tree = Parsing.p_module(s, pxd, full_module_name)
>>> exit
% ./scripts/push_version.sh --allow-dirty-code  
```
